@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.08';
+$VERSION = '5.10';
 
 =head1 NAME
 
@@ -24,7 +24,7 @@ require Exporter;
 @ISA = qw(Exporter);
 %EXPORT_TAGS = ( 'all' => [ qw(
         LegalTag LegalTags CleanTags
-        CleanHTML SafeHTML CleanLink CleanWords
+        CleanHTML SafeHTML CleanLink CleanWords LinkTitles
         DropDownList DropDownListText
         DropDownRows DropDownRowsText
         DropDownMultiList DropDownMultiRows
@@ -94,6 +94,12 @@ Attempts to remove known spam style links.
 
 Attempts to remove known profanity words.
 
+=item LinkTitles
+
+Given a XHTML snippet, will look for basic links and add title attributes.
+Titles are of rhe format 'External Site: $domain', where $domain is the domain
+used in the link.
+
 =back
 
 =cut
@@ -186,6 +192,23 @@ sub CleanWords {
     return $text;
 }
 
+sub LinkTitles {
+    my $text = shift;
+
+    for my $href ($text =~ m!(<a href="https?://[^/"]+(?:/[^"]*)?">)!g) {
+        my ($link1,$path,$link2) = ($href =~ m!(<a href=")((?:https?://|/)?([^/"]+)(?:/[^"]*)?)">!);
+        $href =~ s!([\\\?\+\-\.()\[\]])!\\$1!sig;
+
+        my $title;
+        $title ||= $settings{pathmap}{$path}    if($settings{pathmap}{$path});
+        $title ||= $settings{titlemap}{$link2}  if($settings{titlemap}{$link2});
+        $title ||= "External Site: $link2";
+        $text =~ s!$href!$link1$path" title="$title">!sgi;
+    }
+
+    return $text;
+}
+
 sub _buildtags {
     return %HTMLTAGS    if(%HTMLTAGS);
 
@@ -853,6 +876,9 @@ BEGIN
                 'rows'      => \&cleanup_attr_number,
                 'cols'      => \&cleanup_attr_number,
         },
+        'label'      => { %attr,
+                'for'       => \&cleanup_attr_text,
+        },
 
         # LAYOUT STYLE
         'style'     => {
